| Filename 				                   | Description                                                           | Host Page                                                                         | Download Link                                                                                                                                |
|---------------------------------|-----------------------------------------------------------------------|-----------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------|
| `ccs_dx_icd10cm_2019_1.csv.gz`  | Mapping between (diagnostic, multi-level) CCS and (diagnostic) ICD-10 | [CCSR Archive](https://hcup-us.ahrq.gov/toolssoftware/ccsr/ccsr_archive.jsp#ccsr) | [CCS for ICD-10-CM Diagnoses, v2019.1 (October 2018) (beta version)](https://hcup-us.ahrq.gov/toolssoftware/ccs10/ccs_dx_icd10cm_2019_1.zip) |
| `ccs_pr_icd10pcs_2020_1.csv.gz` | Mapping between (procedure, multi-level) CCS and (procedure) ICD-10   | [CCSR Archive](https://hcup-us.ahrq.gov/toolssoftware/ccsr/ccsr_archive.jsp#ccsr) | [CCS for ICD-10-PCS Procedures, v2020.1 (beta version)](https://hcup-us.ahrq.gov/toolssoftware/ccs10/ccs_pr_icd10pcs_2020_1.zip)             |
| `$dxref 2015.csv.gz`            | Mapping between (diagnostic, single-level) CCS and (diagnostic) ICD-9 | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Single Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Single_Level_CCS_2015.zip)                                                     |
| `$prref 2015.csv.gz`            | Mapping between (procedure, single-level) CCS and (procedure) ICD-9   | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Single Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Single_Level_CCS_2015.zip)                                                     |
| `dxlabel 2015.csv.gz`           | Description table for (diagnostic, single-level) CCS                  | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Single Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Single_Level_CCS_2015.zip)                                                     |
| `prlabel 2014.csv.gz`           | Description table for (procedure, single-level) CCS                   | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Single Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Single_Level_CCS_2015.zip)                                                     |
| `ccs_multi_dx_tool_2015.csv.gz` | Mapping between (diagnostic, multi-level) CCS and (diagnostic) ICD-9  | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Multi Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Multi_Level_CCS_2015.zip)                                                       |
| `ccs_multi_pr_tool_2015.csv.gz` | Mapping between (procedure, multi-level) CCS and (procedure) ICD-9    | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Multi Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Multi_Level_CCS_2015.zip)                                                       |
| `dxmlabel-13.csv.gz`            | Description table for (diagnostic, multi-level) CCS                   | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Multi Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Multi_Level_CCS_2015.zip)                                                       |
| `prmlabel-09.csv.gz`            | Description table for (procedure, multi-level) CCS                    | [CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/ccs.jsp)                         | [Multi Level CCS](https://hcup-us.ahrq.gov/toolssoftware/ccs/Multi_Level_CCS_2015.zip)                                                       |
